# strategies/ - 417 Lines

Reusable strategy templates.

## Modules

| File | Lines | Purpose |
|------|-------|---------|
| templates.py | 417 | Strategy templates for common patterns |

## Key

`SignalFollowingStrategy`, `MomentumStrategy`, `MeanReversionStrategy`, `LongShortStrategy`
